<?php
/**
 * Title: Portfolio Lite Element
 *
 * Description: Displays four portfolio images having optional custom links
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Don't load directly
if( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// Portfolio Lite Page Options
add_action( 'init', 'cyberchimps_portfolio_lite_page_options' );

function cyberchimps_portfolio_lite_page_options() {
	/**
	 * Set up Portfolio Lite on Page options
	 */

	// set directory
	$directory = get_template_directory_uri();

	$category_terms = get_categories();
			if( !is_wp_error( $category_terms ) ):
				$blog_options['all'] = "All";
				foreach( $category_terms as $term ) {
					$blog_options[$term->cat_ID] = $term->cat_name;
				}
			endif;

	$page_fields = array(
		array(
					'type'    => 'select',
					'id'      => 'cyberchimps_portfolio_posts_category_page',
					'class'   => '',
					'name'    => __( 'Post Category', 'cyberchimps_core' ),
					'options' => $blog_options, __( 'All', 'cyberchimps_core' )
				),
		array(
			'type'  => 'text',
			'id'    => 'cyberchimps_blog_portfolio_lite_title_page',
			'class' => '',
			'name'  => __( 'Portfolio Title', 'cyberchimps_core' ),
			'std'   => __( 'Portfolio title will be displayed here', 'cyberchimps_core' )
		),
	);
	/*
	 * configure your meta box
	 */
	$page_config = array(
		'id'             => 'portfolio_lite_options', // meta box id, unique per meta box
		'title'          => __( 'Portfolio Lite Options', 'cyberchimps_core' ), // meta box title
		'pages'          => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
		'context'        => 'normal', // where the meta box appear: normal (default), advanced, side; optional
		'priority'       => 'low', // order of meta box: high (default), low; optional
		'fields'         => $page_fields, // list of meta fields (can be added by field arrays)
		'local_images'   => false, // Use local or hosted images (meta box images for add/remove)
		'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
	);

	/*
	 * Initiate your meta box
	 */
	$page_meta = new Cyberchimps_Meta_Box( $page_config );
}

// Portfolio Lite element action
add_action( 'portfolio_lite', 'cyberchimps_portfolio_lite_content' );

// Defining content of the portfolio-lite element
function cyberchimps_portfolio_lite_content() {
	// call globals
	global $post;

	// Getting options of portfolio-lite when added to page
	if( is_page() ) {
			$title = get_post_meta($post->ID, 'cyberchimps_blog_portfolio_lite_title_page', true);
			$port_cat = get_post_meta($post->ID, 'cyberchimps_portfolio_posts_category_page', true);
	}

	// Getting options of portfolio-lite when added to blog
	else {
			$title = get_theme_mod('cyberchimps_blog_portfolio_lite_title');	
			$port_cat = get_theme_mod('cyberchimps_portfolio_posts_category');		
	}

	$portfolio_args = array(
				'numberposts'      => 4,
				'offset'           => 0,
				'category'         => $port_cat,
				'orderby'          => 'post_date',
				'order'            => 'ASC',
				'post_type'        => 'post',
				'post_status'      => 'publish',
				'suppress_filters' => false
			);
		$portfolio_posts = get_posts($portfolio_args);
	?>

	<!-- Start of markup for portfolio element -->
	<div id="portfolio" class="row">
		<div id="gallery" class="col-md-12">

			<!-- Display the title -->
			<h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>

			<ul class="row">

			<?php
				foreach($portfolio_posts as $portfolio)
				{ 
					
					$featured_image_url = wp_get_attachment_url( get_post_thumbnail_id( $portfolio->ID ) );

					$portfolio_title = get_the_title( $portfolio->ID );
					$portfolio_link = get_permalink( $portfolio->ID );
					
			?>
					<!-- Portfolio 1 -->
					<li id="portfolio_wrap" class="col-md-3">
						<div class="portfolio-item">
							<a href='<?php echo esc_url( $portfolio_link ); ?>' title='<?php echo esc_attr( $portfolio_title ); ?>'>
								<?php 
									if( ! empty( $featured_image_url ) ) 
									{ ?>
										<img src='<?php echo $featured_image_url; ?>' alt="<?php echo esc_attr( $portfolio_title ); ?>"/>
										<div class='portfolio_caption'><?php echo esc_html( $portfolio_title ); ?></div>
									<?php }
									else
									{ ?>
										<div class='portfolio_caption_title'><?php echo esc_html( $portfolio_title ); ?></div>
									<?php } ?>								
							</a>
						</div>
					</li>
				<?php } ?>
			</ul>
		</div>
		<!-- End of #gallery -->
	</div>  <!-- End of .row -->
	<!-- End of markup for portfolio element -->
<?php
}

?>
