<?php
/**
 * Title: Slider Lite Element
 *
 * Description: Slides three images having optional custom links
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Don't load directly
if( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// Add Slider page options
add_action( 'init', 'cyberchimps_slider_lite_page_options' );

function cyberchimps_slider_lite_page_options() {
    /**
     * Set up Portfolio Lite on Page options
     */

    // set directory
    $directory = get_template_directory_uri();

	$category_terms = get_categories();
			if( !is_wp_error( $category_terms ) ):
				$blog_options['all'] = "All";
				foreach( $category_terms as $term ) {
					$blog_options[$term->cat_ID] = $term->cat_name;
				}
			endif;

    $page_fields	= array(
			array(
					'type'    => 'select',
					'id'      => 'cyberchimps_slider_posts_category_page',
					'class'   => '',
					'name'    => __( 'Post Category', 'cyberchimps_core' ),
					'options' => $blog_options, __( 'All', 'cyberchimps_core' )
				),
    );
    /*
     * configure your meta box
     */
    $page_config = array(
        'id'				=> 'slider_lite_options', // meta box id, unique per meta box
        'title'				=> __( 'Slider Lite Options', 'cyberchimps_core' ), // meta box title
        'pages'				=> array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
        'context'			=> 'normal', // where the meta box appear: normal (default), advanced, side; optional
        'priority'			=> 'low', // order of meta box: high (default), low; optional
        'fields'			=> $page_fields, // list of meta fields (can be added by field arrays)
        'local_images'		=> false, // Use local or hosted images (meta box images for add/remove)
        'use_with_theme'	=> true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
    );

    /*
     * Initiate your meta box
     */
    $page_meta = new Cyberchimps_Meta_Box( $page_config );
}

// Action for Slider Lite
add_action( 'slider_lite', 'cyberchimps_slider_lite_content' );

function cyberchimps_slider_lite_content() {
	global $wp_query, $post;
	// Set directory uri
	$directory_uri = get_template_directory_uri();
	$slide         = array();
	$link          = array();

	if( is_page() ) {
		$slide_cat = get_post_meta($post->ID, 'cyberchimps_slider_posts_category_page', true);
	}	

	else {
		$slide_cat = get_theme_mod('cyberchimps_slider_posts_category');		
		
	}

	$slider_args = array(
				'numberposts'      => 3,
				'offset'           => 0,
				'category'         => $slide_cat,
				'orderby'          => 'post_date',
				'order'            => 'ASC',
				'post_type'        => 'post',
				'post_status'      => 'publish',
				'suppress_filters' => false
			);
	$slides_post = get_posts($slider_args);

	$i = 0;
	$slide_counter = 0;

	foreach( $slides_post as $slides_single ) {

		// Getting ID of the current post
		$post_id = $slides_single->ID;

		// Getting individual options of each post
		if (has_post_thumbnail( $post_id ) )
		{
			$slides[$slide_counter]['img'] = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'large' );
			$slides[$slide_counter]['link'] = get_permalink($post_id); 
		}
				
		$slide_counter++;
		} ?>

	<?php if (isset($slides))
			{ ?>
			<div class="row">
			<div id="slider_lite" class="carousel slide">
				<div class="carousel-inner">
			
						<?php foreach ($slides as $slide): ?>
						<?php if ($slide['img'][0] != ''): ?>
						<?php if ($i == 0): ?>
						<div class="active item">
							<?php else: ?>
						<div class="item">
							<?php endif; ?>
							<a href="<?php echo esc_url( $slide['link'] ); ?>">
								<img src="<?php echo esc_url( $slide['img'][0] ); ?>" alt="<?php esc_html_e( 'Slider image', 'cyberchimps_core' ); ?>""/>
							</a>
						</div>
							<?php endif; ?>
							<?php $i++;
							endforeach;
							?>				
					</div>

					<!-- Slider nav -->
					<a class="carousel-control left slider-lite-left" href="#slider_lite" data-slide="prev">&lsaquo;</a>
					<a class="carousel-control right slider-lite-right" href="#slider_lite" data-slide="next">&rsaquo;</a>

				</div>
			</div><!-- row -->
	<?php } // end if isset slides ?>	
<?php
}

?>
