<?php
/**
 * Title: featuredr Lite Element
 *
 * Description: Slides three images having optional custom links
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Don't load directly
if( !defined( 'ABSPATH' ) ) {
	die( '-1' );
}


if( !function_exists( 'cyberchimps_get_option' ) ) {

	/**
	 * Get Option.
	 *
	 * Helper function to return the theme option value.
	 * If no value has been saved, it returns $default.
	 * Needed because options are saved as serialized strings.
	 */

	function cyberchimps_get_option( $name, $default = false ) {
		$options = get_option( 'cyberchimps_options' );

		if( isset( $options[$name] ) ) {
			return $options[$name];
		}

		return $default;
	}
}
// Add Slider page options
add_action( 'init', 'cyberchimps_featured_lite_page_options' );

function cyberchimps_featured_lite_page_options() {
    /**
     * Set up Portfolio Lite on Page options
     */

    // set directory
    $directory = get_template_directory_uri();

    $page_fields	= array(
        // Image one
        array(
        		'name'    => __( 'Featured Area Title', 'charitypure' ),
        		'id'      => 'featuredarea_title',
        		'std'     => __( 'This is Featured Area Title', 'charitypure' ),
        		'type'    => 'text',
        		'section' => 'cyberchimps_featuredarea_section',
        		'heading' => 'cyberchimps_blog_heading'
        ),
        array(
        		'name'    => __( 'Featured Area Text', 'charitypure' ),
        		'id'      => 'featuredarea_text',
        		'std'     => __( 'Here you can place Featured Area Text.', 'charitypure' ),
        		'type'    => 'editor',
        		'section' => 'cyberchimps_featuredarea_section',
        		'heading' => 'cyberchimps_blog_heading'
        ),
        array(
        		'name'    => __( 'Featured Area Button1 Text', 'charitypure' ),
        		'id'      => 'featuredarea_button1_text',
        		'class'   => 'featuredarea_button1_toggle',
        		'std'     => __( 'Free Responsive Themes', 'charitypure' ),
        		'type'    => 'text',
        		'section' => 'cyberchimps_featuredarea_section',
        		'heading' => 'cyberchimps_blog_heading'
        ),
		array(
				'name'    => __( 'Featured Area Button1 URL', 'charitypure' ),
				'id'      => 'featuredarea_button1_url',
				'class'   => 'featuredarea_button1_toggle',
				'std'     => '',
				'type'    => 'text',
				'section' => 'cyberchimps_featuredarea_section',
				'heading' => 'cyberchimps_blog_heading'
        ),
    	array(
    			'name'    => __( 'Featured Area Button2 Text', 'charitypure' ),
    			'id'      => 'featuredarea_button2_text',
    			'class'   => 'featuredarea_button2_toggle',
    			'std'     => __( 'Explore Pro Themes', 'charitypure' ),
    			'type'    => 'text',
    			'section' => 'cyberchimps_featuredarea_section',
    			'heading' => 'cyberchimps_blog_heading'
    		),
    	array(
    			'name'    => __( 'Featured Area Button2 URL', 'charitypure' ),
    			'id'      => 'featuredarea_button2_url',
    			'class'   => 'featuredarea_button2_toggle',
    			'std'     => '',
    			'type'    => 'text',
    			'section' => 'cyberchimps_featuredarea_section',
    			'heading' => 'cyberchimps_blog_heading'
    	),
    array(
    		'name'    => __( 'Featured Area Background Image', 'charitypure' ),
    		'id'      => 'featuredarea_backgroundimage',
    		'class'   => 'custom_featuredbg_options_toggle',
    		'std'     => '',
    		'type'    => 'single_image',
    		'section' => 'cyberchimps_featuredarea_section',
    		'heading' => 'cyberchimps_blog_heading'
			),
			array(
					'name'    => __( 'Featured Area Content Image', 'charitypure' ),
					'id'      => 'featuredarea_contentimage',
					'class'   => 'custom_featuredbg_options_toggle',
					'std'     => '',
					'type'    => 'single_image',
					'section' => 'cyberchimps_featuredarea_section',
					'heading' => 'cyberchimps_blog_heading'
					),
					array(
							'name'    => __( 'Featured Title Color', 'charitypure' ),
							'id'      => 'featured_title_color',
							'class'   => 'custom_featuredbg_options_toggle',
							'std'     => '',
							'type'    => 'color',
							'section' => 'cyberchimps_featuredarea_section',
							'heading' => 'cyberchimps_blog_heading'
							),
							array(
									'name'    => __( 'Featured Text Color', 'charitypure' ),
									'id'      => 'featured_text_color',
									'class'   => 'custom_featuredbg_options_toggle',
									'std'     => '',
									'type'    => 'color',
									'section' => 'cyberchimps_featuredarea_section',
									'heading' => 'cyberchimps_blog_heading'
									),
									array(
											'name'    => __( 'Button 1 Background Color', 'charitypure' ),
											'id'      => 'featured_button1_backcolor',
											'class'   => 'custom_featuredbg_options_toggle',
											'std'     => '',
											'type'    => 'color',
											'section' => 'cyberchimps_featuredarea_section',
											'heading' => 'cyberchimps_blog_heading'
											),
											array(
													'name'    => __( 'Button 1 Text Color', 'charitypure' ),
													'id'      => 'featured_button1_color',
													'class'   => 'custom_featuredbg_options_toggle',
													'std'     => '',
													'type'    => 'color',
													'section' => 'cyberchimps_featuredarea_section',
													'heading' => 'cyberchimps_blog_heading'
													),
													array(
															'name'    => __( 'Button 2 Text Color', 'charitypure' ),
															'id'      => 'featured_button1_color',
															'class'   => 'custom_featuredbg_options_toggle',
															'std'     => '',
															'type'    => 'color',
															'section' => 'cyberchimps_featuredarea_section',
															'heading' => 'cyberchimps_blog_heading'
															)

    );
    /*
     * configure your meta box
     */
    $page_config = array(
        'id'				=> 'featured_lite_options', // meta box id, unique per meta box
        'title'				=> __( 'Featured Lite Options', 'cyberchimps_core' ), // meta box title
        'pages'				=> array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
        'context'			=> 'normal', // where the meta box appear: normal (default), advanced, side; optional
        'priority'			=> 'low', // order of meta box: high (default), low; optional
        'fields'			=> $page_fields, // list of meta fields (can be added by field arrays)
        'local_images'		=> false, // Use local or hosted images (meta box images for add/remove)
        'use_with_theme'	=> true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
    );

    /*
     * Initiate your meta box
     */
    $page_meta = new Cyberchimps_Meta_Box( $page_config );
}

// Action for Slider Lite
add_action( 'featured_lite', 'cyberchimps_featured_lite_content' );

function cyberchimps_featured_lite_content() {
	global $wp_query, $post;

	// Set directory uri
	$directory_uri = get_template_directory_uri();
	$slide         = array();
	$link          = array();

	if( is_page() ) {
		$featuredarea_title                     = ( get_post_meta( $post->ID, 'featuredarea_title', true ) ) ? get_post_meta( $post->ID, 'featuredarea_title', true ) : '';
		$featuredarea_text                      = ( get_post_meta( $post->ID, 'featuredarea_text', true ) ) ? get_post_meta( $post->ID, 'featuredarea_text', true ) : '';
		$featuredarea_button1_text              = ( get_post_meta( $post->ID, 'featuredarea_button1_text', true ) ) ? get_post_meta( $post->ID, 'featuredarea_button1_text', true ) : '';
		$featuredarea_button1_url               = ( get_post_meta( $post->ID, 'featuredarea_button1_url', true ) ) ? get_post_meta( $post->ID, 'featuredarea_button1_url', true ) : '';
		$featuredarea_button2_text              = (  get_post_meta( $post->ID, 'featuredarea_button2_text', true ) ) ? get_post_meta( $post->ID, 'featuredarea_button2_text', true ) : '';
		$featuredarea_button2_url               = ( get_post_meta( $post->ID, 'featuredarea_button2_url', true ) ) ? get_post_meta( $post->ID, 'featuredarea_button2_url', true ) : '';
		$featuredarea_backgroundimage           = ( get_post_meta( $post->ID, 'featuredarea_backgroundimage', true ) ) ? get_post_meta( $post->ID, 'featuredarea_backgroundimage', true ) : '';
		$featuredarea_contentimage           = ( get_post_meta( $post->ID, 'featuredarea_contentimage', true ) ) ? get_post_meta( $post->ID, 'featuredarea_contentimage', true ) : '';
    $featured_title_color           = ( get_post_meta( $post->ID, 'featured_title_color', true ) ) ? get_post_meta( $post->ID, 'featured_title_color', true ) : '';
		$featured_text_color           = ( get_post_meta( $post->ID, 'featured_text_color', true ) ) ? get_post_meta( $post->ID, 'featured_text_color', true ) : '';
		$featured_button1_backcolor           = ( get_post_meta( $post->ID, 'featured_button1_backcolor', true ) ) ? get_post_meta( $post->ID, 'featured_button1_backcolor', true ) : '';
		$featured_button1_color           = ( get_post_meta( $post->ID, 'featured_button1_color', true ) ) ? get_post_meta( $post->ID, 'featured_button1_color', true ) : '';
		$featured_button2_color           = ( get_post_meta( $post->ID, 'featured_button2_color', true ) ) ? get_post_meta( $post->ID, 'featured_button2_color', true ) : '';
	}
	else {

		$featuredarea_title = cyberchimps_get_option( 'bl_featuredarea_title', 'This is Featured Area Title' );
		$featuredarea_text                      = cyberchimps_get_option( 'bl_featuredarea_text', 'Here you can place Featured Area Text' );
		$featuredarea_button1_text              = cyberchimps_get_option( 'bl_featuredarea_button1_text', 'Free Responsive Themes' );
		$featuredarea_button1_url               = cyberchimps_get_option( 'bl_featuredarea_button1_url', 'CyberChimps' );
		$featuredarea_button2_text              = cyberchimps_get_option( 'bl_featuredarea_button2_text', 'Explore Pro Themes' );
		$featuredarea_button2_url               = cyberchimps_get_option( 'bl_featuredarea_button2_url', '' );
		$featuredarea_backgroundimage		= cyberchimps_get_option( 'bl_featuredarea_backgroundimage', '' );
		$featuredarea_contentimage		= cyberchimps_get_option( 'bl_featuredarea_contentimage', '' );
		$featured_title_color		= cyberchimps_get_option( 'featured_title_color', '' );
		$featured_text_color		= cyberchimps_get_option( 'featured_text_color', '' );
		$featured_button1_backcolor		= cyberchimps_get_option( 'featured_button1_backcolor', '' );
		$featured_button1_color		= cyberchimps_get_option( 'featured_button1_color', '' );
		$featured_button2_color		= cyberchimps_get_option( 'featured_button2_color', '' );
	}

	$i = 0;
/*
$featuredarea_title = $featuredarea_title ? $featuredarea_title : 'Featured Area Title';
$featuredarea_text = $featuredarea_text ? $featuredarea_text : 'Featured Area Text';
$featuredarea_button1_text = $featuredarea_button1_text ? $featuredarea_button1_text : 'Button 1';
$featuredarea_button2_text = $featuredarea_button2_text ? $featuredarea_button2_text : 'Button 2';
*/

$cyberchimps_display_featured = ( get_theme_mod( 'cyberchimps_display_featured', 1 ) ) ? get_theme_mod( 'cyberchimps_display_featured', 1 ) : false;



$featured_title_color = $featured_title_color ? $featured_title_color : '#000';
$featured_text_color = $featured_text_color ? $featured_text_color : '#000';
$featured_button1_backcolor = $featured_button1_backcolor ? $featured_button1_backcolor : '#2082b5';
$featured_button1_color = $featured_button1_color ? $featured_button1_color : '#fff';
$featured_button2_color = $featured_button2_color ? $featured_button2_color : '#000';

	?>
	<style>
    #featured_lite_section{  background: none repeat scroll 0 0; background-image: url('<?php echo $featuredarea_backgroundimage;?>');background-size: cover;}
		.featured-title{ color: <?php echo $featured_title_color; ?> }
		.featured-text{ color: <?php echo $featured_text_color; ?> }
		.featured-buttons a.featured-button1{ background-color: <?php echo $featured_button1_backcolor; ?>}
		.featured-buttons a.featured-button1{ border: <?php echo $featured_button1_backcolor; ?> }
		.featured-buttons a.featured-button1{ color: <?php echo $featured_button1_color; ?> !important; }
		.featured-buttons a.featured-button2{ color: <?php echo $featured_button2_color; ?> !important; }
		.featured-buttons a.featured-button2{ border: 1px solid <?php echo $featured_button2_color; ?> !important; }
</style>
			<!-- FeaturedArea without button -->
			<div id="featuredarea_container" class="row">
				<div id="featuredarea" class="col-md-12" >
					<div class="featuredarea-content-container">
						<div class="featuredarea-content">
							<?php if($featuredarea_contentimage) {?>
							<div class="featured-img-container col-md-3 col-sm-12">
								<img class="featured-image" src="<?php echo $featuredarea_contentimage; ?>" />
							</div>
							<?php }
								else { ?>
									<style>
										.featured-text-container
										{
												text-align: center;
										}
									</style>
							<?php	}?>
							<div class="featured-text-container col-md-9 col-sm-12">
								<h2 class="featured-title" ><?php echo $featuredarea_title ?></h2>
								<div class="featured-text" ><?php echo $featuredarea_text ?></div>
								<div class="featured-buttons">
									<?php if( !empty( $featuredarea_button1_text ) ){ ?>
										<a href="<?php echo $featuredarea_button1_url; ?>" class="btn btn-large btn-primary featured-button1"><?php echo $featuredarea_button1_text; ?></a>
									<?php } ?>
									<?php if( !empty( $featuredarea_button2_text ) ){ ?>
										<a href="<?php echo $featuredarea_button2_url; ?>" class="btn btn-large btn-primary featured-button2"><?php echo $featuredarea_button2_text; ?></a>
									<?php } ?>
								</div>
							</div>
						</div>
						<!-- #featuredarea-text -->
					</div>
				</div>
				<!-- .row-fluid .span12 -->
			</div><!-- row-fluid -->

<?php
}

?>
